<?xml version="1.0" encoding="UTF-8"?>

<!-- Ensures that certain prefixes are exxcluded from  -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0 " xmlns:hl7="urn:hl7-org:v3" xmlns:mo="http://extensions.your-healthcare.org"
  exclude-result-prefixes="hl7 mo">


  <xsl:output method="xml"/>

  <!-- Entry Point; replicate the top element -->

  <xsl:template match="/hl7:ClinicalDocument" mode="mo:MyMODEname">
    <hl7:ClinicalDocument>
      <xsl:apply-templates select="@*" mode="mo:MyMODEname"/>
      <xsl:apply-templates select="node()" mode="mo:MyMODEname"/>
    </hl7:ClinicalDocument>
  </xsl:template>

  <!-- copy all attributes, elements, and text nodes anywhere in the document -->
  <xsl:template match="node()" mode="mo:MyMODEname" priority="1">
    <xsl:copy>
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates select="node()" mode="mo:MyMODEname"/>
    </xsl:copy>
  </xsl:template>

  <!-- Translates certain punctuation within node values to an empty string-->

<xsl:template match="text()" mode="mo:MyMODEname"  priority="2">
	<xsl:value-of select="translate(., '?!', '')"/>
</xsl:template>

  <!-- For certain hl7:encounter/hl7:effectiveTime elements, ensure that it has both low and high timestamp, or neither -->
  <xsl:template
    match="/hl7:ClinicalDocument/hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:templateId/@root = '2.16.840.1.113883.10.20.22.2.22']/hl7:entry/hl7:encounter/hl7:effectiveTime"
    mode="mo:MyMODEname" priority="3">
     <xsl:comment>highest priority template</xsl:comment>
    <xsl:copy>
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates select="node()" mode="mo:MyMODEname"/>

      <!--If test adds a high node where low node is present and high node is missing. It copies the value of the low node to the new high node. -->
      <xsl:if test="string-length(hl7:low/@value) > 0 and not(string-length(hl7:high/@value) > 0)">
        <xsl:comment>hl7:timestamp was augmented in pre-processing phase</xsl:comment>
        <xsl:element name="high" namespace="urn:hl7-org:v3">
          <xsl:attribute name="value">
            <xsl:value-of select="hl7:low/@value"/>
          </xsl:attribute>
        </xsl:element>
      </xsl:if>
    </xsl:copy>
  </xsl:template>

</xsl:stylesheet>